@@ -325,7 +325,7 @@ def left_boundary(linkp, pn, H, V, H0, V0, links2, p, pump, valve, dt,
     elif dtype[0] == 'Valve':
         valvec = valve[1]
         if links2 == []:
-            H[i], V[i] = valve_end (H1, V1, V[i], n, a, g, f, D, dt,
+            H[n], V[n] = valve_end (H1, V1, V[n], n, a, g, f, D, dt,
             KD, friction, dVdx1, dVdt1)
         else:
             H[n], V[n] = valve_node(valvec, linkp, link2,
